==> ttcomment-0.0.1.tar.gz: lib/comment_widget/comment_state.dart <==
/*
 * @Descripttion: 
 * @version: 
 * @Author: TT
 * @Date: 2021-11-01 22:28:02
 * @LastEditors: TT
 * @LastEditTime: 2022-05-01 23:16:04
 */

import 'package:flutter/material.dart';
import 'package:ttcomment/ttcomment.dart';

/// 刷新界面 规范
abstract class AbstracRefreshWidget {
  /// 创建刷新控件
  Widget createRefreshWidget(BuildContext context);

  /// 创建列表
  Widget createListView(BuildContext context);

  /// 创建列表 item
  Widget createListitem(BuildContext context, int index);

  /// 创建缺省页界面
  Widget? createEmptyWidget();
}

/// 刷新界面 触发方法
abstract class AbstracRefreshMehod {
  int page = 1;

  /// 结束刷新
  void endRefresh(int type, PageState pageState);

  /// 下啦刷新 触发事件
  void configRefresh();

  /// 上啦加载 触发事件
  void configLoading();
}

abstract class AbstractAttribute {
  /// 导航栏标题
  final String? title = null;

  /// 导航栏颜色
  final Color? navbackcolor = null;

  /// 默认安全区顶部 忽略
  final bool safeAreatop = true;

  /// 默认安全区底部 忽略
  final bool safeAreabottm = true;

  /// 网络加载状态
  final PageState pageState = PageState.initializedState;

  /// 背景颜色
  final Color? backgroundColor = null;

  /// 是否显示 加载动画 默认不显示

  /// 滚动属性
  final bool? resizeToAvoidBottomInset = null;
}

// 配置网络请求规范
abstract class AbstractNetWork {
  @protected
  Map<String, dynamic>? configNetWorkParmas();

  /// 网络请求
  @protected
  void getnetworkdata(int? type, Map<String, dynamic>? info);
}

// 普通界面 规范
abstract class AbstractWidget {
  /// 创建scaffoll
  Widget createScaffol({
    required BuildContext context,
    required bool safeAreatop,
    required bool safeAreabottm,
    required PageState pageState,
    required String? title,
    required Color? backgroundColor,
    required Color? navbackcolor,
    required bool? resizeToAvoidBottomInset,
  }) {
    return Scaffold(
      resizeToAvoidBottomInset: resizeToAvoidBottomInset,
      backgroundColor: backgroundColor,
      appBar: createAppBar(
        context,
        title: title,
        navbackcolor: navbackcolor,
      ),
      body: createSafeArea(
        context,
        safeAreatop,
        safeAreabottm,
        pageState,
      ),
    );
  }

  /// 创建safe
  Widget createSafeArea(
    BuildContext context,
    bool safeAreatop,
    bool safeAreabottm,
    PageState pageState,
  ) {
    return SafeArea(
      child: createCommBaseWidget(
        context,
        pageState,
      ),
      top: safeAreatop,
      bottom: safeAreabottm,
    );
  }

  /// 创建导航栏
  PreferredSize? createAppBar(
    BuildContext context, {
    Color? navbackcolor,
    String? title,
  }) {
    if (title != null) {
      return AppBarGenerator.getNoramlAppBar(
          context: context,
          title: title,
          backgroundColor: navbackcolor,
          actions: createAppBaractions(),
          leading: createAppBarleading(),
          textColor: createAppBarTextColor(),
          leadingIconColor: createLeadingIconColor(),
          leadingCallback: () {
            configleadingCallbak(context);
          },
          titlew: createAppBarTitleWidget());
    }
    return null;
  }

  Widget? createAppBarTitleWidget() {
    return null;
  }

  Color? createLeadingIconColor() {
    return null;
  }

  Color? createAppBarTextColor() {
    return null;
  }

  /// 创建导航栏 右边按钮集合
  List<Widget>? createAppBaractions() {
    return null;
  }

  /// 重写返回按钮控件
  Widget? createAppBarleading() {
    return null;
  }

  /// 创建通用站位界面
  Widget createCommBaseWidget(
    BuildContext context,
    PageState pageState,
  ) {
    return CommonBasePage(
      pageState: pageState,
      child: createColumWidget(context),
      errorWidget: createErrorWidget(),
    );
  }

  /// 创建界面Colum
  Widget createColumWidget(BuildContext context) {
    return Column(
      children: [
        createHeaderWidget(),
        Expanded(
          child: createBody(context),
        ),
      ],
    );
  }

  /// 创建头部
  Widget createHeaderWidget() {
    return Container();
  }

  /// 创建真实body
  @protected
  Widget createBody(BuildContext context);

  /// 创建失败 界面
  Widget? createErrorWidget() {
    return null;
  }

  /// 点击通用返回按钮点击事件
  configleadingCallbak(BuildContext context) {
    configgoback(context);
  }

  /// 执行返回界面
  configgoback(BuildContext context) {
    Navigator.of(context).pop();
  }
}

abstract class TTStatelessWidget extends StatelessWidget
    with AbstractWidget, AbstractNetWork, AbstractAttribute {
  TTStatelessWidget({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return createScaffol(
        context: context,
        safeAreatop: safeAreatop,
        safeAreabottm: safeAreabottm,
        pageState: pageState,
        title: title,
        backgroundColor: backgroundColor,
        navbackcolor: navbackcolor,
        resizeToAvoidBottomInset: resizeToAvoidBottomInset);
  }

  @override
  Map<String, dynamic>? configNetWorkParmas() {
    return null;
  }

  @override
  void getnetworkdata(int? type, Map<String, dynamic>? info) async {}
}

abstract class TTNormalStatefulWidget extends StatefulWidget {
  const TTNormalStatefulWidget({Key? key}) : super(key: key);

  @override
  // ignore: no_logic_in_create_state
  TTNormalState createState() => getState();
  TTNormalState getState();
}

abstract class TTNormalState<T extends TTNormalStatefulWidget> extends State<T>
    with AbstractWidget, AbstractNetWork, AbstractAttribute {
  @override
  void initState() {
    initDefaultState();
    super.initState();
  }

  @override
  void dispose() {
    initDefaultDispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return createScaffol(
      context: context,
      safeAreatop: safeAreatop,
      safeAreabottm: safeAreabottm,
      pageState: pageState,
      title: title,
      backgroundColor: backgroundColor,
      navbackcolor: navbackcolor,
      resizeToAvoidBottomInset: resizeToAvoidBottomInset,
    );
  }

  /// 界面进入
  void initDefaultState() {
    configNormalData();
  }

  /// 界面销毁
  void initDefaultDispose() {}

  void configsetState(VoidCallback fn) {
    if (mounted) {
      setState(() {
        fn();
      });
    }
  }
  // 网络请求

  @override
  Map<String, dynamic>? configNetWorkParmas() {
    return {};
  }

  void configNormalData() {}

  @override
  void getnetworkdata(int? type, Map<String, dynamic>? info) async {}
}

==> ttcomment-0.0.3.tar.gz: lib/comment_widget/comment_state.dart <==
/*
 * @Descripttion: 
 * @version: 
 * @Author: TT
 * @Date: 2021-11-01 22:28:02
 * @LastEditors: TT
 * @LastEditTime: 2022-08-24 15:35:06
 */

import 'package:flutter/material.dart';
import 'package:ttcomment/ttcomment.dart';

/// 刷新界面 规范
abstract class AbstracRefreshWidget {
  /// 创建刷新控件
  Widget createRefreshWidget(BuildContext context);

  /// 创建列表
  Widget createListView(BuildContext context);

  /// 创建列表 item
  Widget createListitem(BuildContext context, int index);

  /// 创建缺省页界面
  Widget? createEmptyWidget();
}

/// 刷新界面 触发方法
abstract class AbstracRefreshMehod {
  int page = 1;

  /// 结束刷新
  void endRefresh(int type, PageState pageState);

  /// 下啦刷新 触发事件
  void configRefresh();

  /// 上啦加载 触发事件
  void configLoading();
}

abstract class AbstractAttribute {
  /// 导航栏标题
  final String? title = null;

  /// 导航栏颜色
  final Color? navbackcolor = null;

  /// 默认安全区顶部 忽略
  final bool safeAreatop = true;

  /// 默认安全区底部 忽略
  final bool safeAreabottm = true;

  /// 网络加载状态
  final PageState pageState = PageState.initializedState;

  /// 背景颜色
  final Color? backgroundColor = null;

  /// 是否显示 加载动画 默认不显示

  /// 滚动属性
  final bool? resizeToAvoidBottomInset = null;
}

// 配置网络请求规范
abstract class AbstractNetWork {
  @protected
  Map<String, dynamic>? configNetWorkParmas();

  /// 网络请求
  @protected
  void getnetworkdata(int? type, Map<String, dynamic>? info);
}

// 普通界面 规范
abstract class AbstractWidget {
  /// 创建scaffoll
  Widget createScaffol({
    required BuildContext context,
    required bool safeAreatop,
    required bool safeAreabottm,
    required PageState pageState,
    required String? title,
    required Color? backgroundColor,
    required Color? navbackcolor,
    required bool? resizeToAvoidBottomInset,
  }) {
    return Scaffold(
      resizeToAvoidBottomInset: resizeToAvoidBottomInset,
      backgroundColor: backgroundColor,
      appBar: createAppBar(
        context,
        title: title,
        navbackcolor: navbackcolor,
      ),
      body: createSafeArea(
        context,
        safeAreatop,
        safeAreabottm,
        pageState,
      ),
    );
  }

  /// 创建导航栏
  PreferredSize? createAppBar(
    BuildContext context, {
    Color? navbackcolor,
    String? title,
  }) {
    if (title != null) {
      return AppBarGenerator.getNoramlAppBar(
        context: context,
        title: title,
        backgroundColor: navbackcolor,
        actions: createAppBaractions(),
        leading: createAppBarleading(),
        textColor: createAppBarTextColor(),
        leadingIconColor: createLeadingIconColor(),
        leadingCallback: () {
          configleadingCallbak(context);
        },
        titlew: createAppBarTitleWidget(),
        bottom: createAppBarBottomWidget(),
      );
    }
    return null;
  }

  /// 自定义appBar title
  Widget? createAppBarTitleWidget() {
    return null;
  }

  /// 设置系统返回按钮 icon 颜色
  Color? createLeadingIconColor() {
    return null;
  }

  /// 设置默认 title 字体颜色
  Color? createAppBarTextColor() {
    return null;
  }

  /// 创建导航栏 右边按钮集合
  List<Widget>? createAppBaractions() {
    return null;
  }

  /// 重写返回按钮控件
  Widget? createAppBarleading() {
    return null;
  }

  /// 创建AppBar bottom
  PreferredSizeWidget? createAppBarBottomWidget() {
    return null;
  }

  /// 创建safe
  Widget createSafeArea(
    BuildContext context,
    bool safeAreatop,
    bool safeAreabottm,
    PageState pageState,
  ) {
    return SafeArea(
      child: createCommBaseWidget(
        context,
        pageState,
      ),
      top: safeAreatop,
      bottom: safeAreabottm,
    );
  }

  /// 创建通用站位界面
  Widget createCommBaseWidget(
    BuildContext context,
    PageState pageState,
  ) {
    return CommonBasePage(
      pageState: pageState,
      child: createColumWidget(context),
      errorWidget: createErrorWidget(),
    );
  }

  /// 创建界面Colum
  Widget createColumWidget(BuildContext context) {
    return Column(
      children: [
        createHeaderWidget(),
        Expanded(
          child: createBody(context),
        ),
      ],
    );
  }

  /// 创建头部
  Widget createHeaderWidget() {
    return Container();
  }

  /// 创建真实body
  @protected
  Widget createBody(BuildContext context);

  /// 创建失败 界面
  Widget? createErrorWidget() {
    return null;
  }

  /// 点击通用返回按钮点击事件
  configleadingCallbak(BuildContext context) {
    configgoback(context);
  }

  /// 执行返回界面
  configgoback(BuildContext context) {
    Navigator.of(context).pop();
  }
}

abstract class TTStatelessWidget extends StatelessWidget
    with AbstractWidget, AbstractNetWork, AbstractAttribute {
  TTStatelessWidget({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return createScaffol(
        context: context,
        safeAreatop: safeAreatop,
        safeAreabottm: safeAreabottm,
        pageState: pageState,
        title: title,
        backgroundColor: backgroundColor,
        navbackcolor: navbackcolor,
        resizeToAvoidBottomInset: resizeToAvoidBottomInset);
  }

  @override
  Map<String, dynamic>? configNetWorkParmas() {
    return null;
  }

  @override
  void getnetworkdata(int? type, Map<String, dynamic>? info) async {}
}

abstract class TTNormalStatefulWidget extends StatefulWidget {
  const TTNormalStatefulWidget({Key? key}) : super(key: key);

  @override
  // ignore: no_logic_in_create_state
  TTNormalState createState() => getState();
  TTNormalState getState();
}

abstract class TTNormalState<T extends TTNormalStatefulWidget> extends State<T>
    with AbstractWidget, AbstractNetWork, AbstractAttribute {
  @override
  Color? get backgroundColor => Colors.white;

  @override
  Color? get navbackcolor => configbackColor();

  Color? configbackColor() {
    return null;
  }

  @override
  void initState() {
    initDefaultState();
    super.initState();
  }

  @override
  void dispose() {
    initDefaultDispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return createScaffol(
      context: context,
      safeAreatop: safeAreatop,
      safeAreabottm: safeAreabottm,
      pageState: pageState,
      title: title,
      backgroundColor: backgroundColor,
      navbackcolor: navbackcolor,
      resizeToAvoidBottomInset: resizeToAvoidBottomInset,
    );
  }

  /// 界面进入
  void initDefaultState() {
    configNormalData();
  }

  /// 界面销毁
  void initDefaultDispose() {}

  void configsetState(VoidCallback fn) {
    if (mounted) {
      setState(() {
        fn();
      });
    }
  }
  // 网络请求

  @override
  Map<String, dynamic>? configNetWorkParmas() {
    return {};
  }

  void configNormalData() {}

  @override
  void getnetworkdata(int? type, Map<String, dynamic>? info) async {}
}
